/* Part of Replication files for Sarzosa and Urzua "Bullying Among Adolescents: 
   The Role of Skills" in QE.
   
   Miguel Sarzosa (msarzosa@purdue.edu)
   Sergio Urzua (surzua@econ.umd.edu)
   
   December 2020
*/

args outvar choice corr w model name simsmod 

********************************************************************************
* 0. Housecleaning   
********************************************************************************

set more off
clear all
set maxvar 20000
set matsize 1000
set seed 12345


********************************************************************************
* 2. Loading Programs
********************************************************************************

if substr("`corr'",1,4)=="step" local step = substr("`corr'",1,5)

if "`step'"=="step7" qui do Codes/ados/heterofactorJointHHM.ado
if inlist("`step'","step1","step3","step5","step6") & "`corr'"!="step1_lesscont" qui do Codes/ados/heterofactorJointHHM_`step'.ado
if "`corr'"=="step1_lesscont" qui do Codes/ados/heterofactorJointHHM_step1.ado

// This one is HHM joint
if "`corr'"=="second" qui do Codes/ados/heterofactorJointHHM_2step.ado
qui do Codes/ados/random_dist2f.ado
qui do Codes/ados/simulfact_JointHHM_Roy.ado
qui do Codes/ados/simulfact_Joint_mpc.ado

program loom, sortpreserve
	args var group
	bys `group': egen tg = sum(`var')
	bys `group': gen ng = _n if `var'!=.
	bys `group': egen mng = max(ng)
	gen `var'loo = (tg -`var')/(mng-1)
	drop tg ng mng
end



********************************************************************************
* 3. Correlated Skills with Hansen, Heckman and Mullen (2004) specification
********************************************************************************

use Data/KoreaJHS_Distr.dta

/* Given the computational requirement of the model, we estimate this sequentially
   taking as previous/simple models as inputs for initial values in more 
   complicated ones. */

********************************************************************************
* 3.1 Fewer controls
********************************************************************************

if "`corr'"=="step1_lesscont" {
		
	local controls "ageinmonths male" 

	cap log close
	log using Results/logs/FirstStageJoint`name'_w`w'_newcodeHHM_`corr'.txt, text replace
	cap noisily heterofactor `outvar' `controls' if wave==`w' & sample==1, treatindbef(`choice') /// 
		instrum(`controls') /// 
		scores(locus_std irrespons_std selfest_std categradeLangSS_std categradeMathSc_std rankclassscore_std) /// 
		indvarsc(`controls') factors(2) triangular joint difficult fdistonly initialreg 
	est save Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_`corr', replace
	log close	
}

********************************************************************************
* 3.2 More controls, few instuments
********************************************************************************

if inlist("`corr'","step1fi","step3fi") {
	
	local controls "ageinmonths male oldersiblings youngsiblings lnmonthinc_pc urban liveswbothparents onlymother fathereduc2yColl fathereduc4yColl fathereducGS"		
	
	if "`step'"=="step1" est use Results/Regs/FirstStageJointRR_w1_newcodeHHM_step1_lesscont.ster
	if "`step'"=="step3" est use Results/Regs/FirstStageJointRR_w1_newcodeHHM_step1.ster
	mat b = e(b)
	if "`step'"=="step1" mat inval = b[1,22..44]
	if "`step'"=="step3" mat inval = b[1,85..92],b[1,87..88],b[1,93..95],b[1,93..94],b[1,96..107]

	cap log close
	if "`step'"=="step1" log using Results/logs/FirstStageJoint`name'_w`w'_newcodeHHM_`corr'_morecont.txt, text replace
	else log using Results/logs/FirstStageJoint`name'_w`w'_newcodeHHM_`corr'.txt, text replace

	cap noisily cap noisily heterofactor `outvar' `controls' if wave==`w' & sample==1, treatindbef(`choice') /// 
		instrum(`controls') /// 
		scores(locus_std irrespons_std selfest_std categradeLangSS_std categradeMathSc_std rankclassscore_std) /// 
		indvarsc(`controls') factors(2) triangular joint difficult fdistonly initialreg inipar(inval)
	est save Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_`step', replace
	ml display
	log close	
}

if inlist("`corr'","step5fi","step6fi","step7fi") {

	
	est use Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_step3
	mat b = e(b)
	if "`step'"=="step5" mat inval = b[1,109..118],b[1,113..114],b[1,119..126],b[1,124],b[1,127..135]
	
	foreach i in locus_std irrespons_std {
		forvalues j=0/1 {
			mat score _xb`i'`j' = b, eq(`i'`j')
			gen _r`i'`j'=`i'-_xb`i'`j'
			drop _xb`i'`j'
		}
		gen _r`i'=_r`i'1
		replace _r`i'=_r`i'0 if `choice'==0
	}
	foreach i in selfest_std categradeMathSc_std rankclassscore_std {
		mat score _xb`i' = b, eq(`i'1)
		gen _r`i'=`i'-_xb`i'
		drop _xb`i'
	}
	if inlist("`step'","step6","step7") {
		drop _rselfest_std 
		est use Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_step5
		mat b = e(b)
		mat inval = b[1,44..47],1,b[1,48..60],b[1,58],b[1,61..73]
		local i categradeLangSS_std 
		forvalues j=0/1 {
			mat score _xb`i'`j' = b, eq(`i'`j')
			gen _r`i'`j'=`i'-_xb`i'`j'
			drop _xb`i'`j'
		}
		gen _r`i'=_r`i'1
		replace _r`i'=_r`i'0 if `choice'==0
		
		if inlist("`step'","step7") {
			drop _rrankclassscore_std
			est use Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_step6
			mat b = e(b)
			mat inval = b[1,45..67],b[1,63],b[1,68..76]
			local i selfest_std 
			forvalues j=0/1 {
				mat score _xb`i'`j' = b, eq(`i'`j')
				gen _r`i'`j'=`i'-_xb`i'`j'
				drop _xb`i'`j'
			}
			gen _r`i'=_r`i'1
			replace _r`i'=_r`i'0 if `choice'==0		
		}		
	}

	local controls "ageinmonths male oldersiblings youngsiblings lnmonthinc_pc urban liveswbothparents onlymother fathereduc2yColl fathereduc4yColl fathereducGS"
	if "`step'"=="step5" local testslist "_rlocus_std _rirrespons_std _rselfest_std categradeLangSS_std _rcategradeMathSc_std _rrankclassscore_std"
	if "`step'"=="step6" local testslist "_rlocus_std _rirrespons_std selfest_std _rcategradeLangSS_std _rcategradeMathSc_std _rrankclassscore_std"
	if "`step'"=="step7" local testslist "_rlocus_std _rirrespons_std _rselfest_std _rcategradeLangSS_std _rcategradeMathSc_std rankclassscore_std"
	
	gen uno=1		
	
	cap log close
	log using Results/logs/FirstStageJoint`name'_w`w'_newcodeHHM_`step'.txt, text replace

	cap noisily heterofactor `outvar' `controls' if wave==`w' & sample==1, treatindbef(`choice') /// 
		instrum(`controls') scores(`testslist') /// 
		indvarsc() exp1(uno) exp2(`controls') factors(2) triangular joint difficult fdistonly initialreg inipar(inval)
	est save Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_`step', replace
	ml display
	log close	
}


********************************************************************************
* 3.2 More controls, more instuments
********************************************************************************

if inlist("`corr'","step1","step3") {

	local controls "ageinmonths male oldersiblings youngsiblings lnmonthinc_pc urban liveswbothparents onlymother fathereduc2yColl fathereduc4yColl fathereducGS"		
	
	
	if "`corr'"=="step3" {
		est use Results/Regs/FirstStageJointRR_w1_newcodeHHM_step3.ster
		local aT110 = _b[aT110:_cons]
		local aT210 = _b[aT210:_cons]
		local sigT10 = _b[sigT10:_cons]
		local sigT20 = _b[sigT20:_cons]		
		est use Results/Regs/FirstStageJointRR_w1_newcodeHHM_Zt0_step1.ster
		local inistr "inipar(inval)"
	}
	if "`corr'"=="step1" est use Results/Regs/FirstStageJointRR_w1_newcodeHHM_step1.ster
	mat b = e(b)
	if "`corr'"=="step1" mat inval = _b[av1:_cons], _b[av2:_cons], _b[aT111:_cons], _b[aT211:_cons], _b[aT411:_cons], _b[aT421:_cons], _b[aT511:_cons], _b[aT521:_cons], _b[sigT11:_cons], _b[sigT21:_cons], _b[sigT31:_cons], _b[sigT41:_cons], _b[sigT51:_cons],  _b[sigT61:_cons], _b[sigf11:_cons], _b[sigf12:_cons], _b[sigf21:_cons],  _b[sigf22:_cons], _b[p1:_cons],  _b[mu11:_cons],  _b[mu21:_cons],  _b[rho1:_cons], _b[rho2:_cons]
	if "`corr'"=="step3" mat inval = _b[av1:_cons], _b[av2:_cons], _b[aT111:_cons], _b[aT211:_cons], _b[aT411:_cons], _b[aT421:_cons], _b[aT511:_cons], _b[aT521:_cons], `aT110',`aT210', _b[sigT11:_cons], _b[sigT21:_cons], _b[sigT31:_cons], `sigT10',`sigT20',_b[sigT41:_cons], _b[sigT51:_cons],  _b[sigT61:_cons], _b[sigf11:_cons], _b[sigf12:_cons], _b[sigf21:_cons],  _b[sigf22:_cons], _b[p1:_cons],  _b[mu11:_cons],  _b[mu21:_cons],  _b[rho1:_cons], _b[rho2:_cons]

	cap log close
	log using Results/logs/FirstStageJoint`name'_w`w'_newcodeHHM_Zt0_`corr'.txt, text replace

	cap noisily heterofactor `outvar' `controls' if wave==`w' & sample==1, treatindbef(`choice') /// 
		instrum(`controls' moveout_adj2002 quit_adj2002) /// 
		scores(locus_std irrespons_std selfest_std categradeLangSS_std categradeMathSc_std rankclassscore_std) /// 
		indvarsc(`controls') factors(2) triangular joint difficult fdistonly initialreg `inistr'
	ml display
	est save Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_Zt0_`corr', replace
	log close
}	

if inlist("`corr'","step5","step6","step7") {
	
	if "`corr'"=="step5" {
		est use Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_`corr'
		local aT410 = _b[aT410:_cons]
		local aT420 = _b[aT420:_cons]
		local sigT40 = _b[sigT40:_cons]
	}
	est use Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_Zt0_step3
	if "`corr'"=="step5" mat inval = _b[av1:_cons], _b[av2:_cons], _b[aT111:_cons], _b[aT211:_cons], _b[aT411:_cons], _b[aT421:_cons], _b[aT511:_cons], _b[aT521:_cons], _b[aT110:_cons], _b[aT210:_cons], `aT410', `aT420', _b[sigT11:_cons], _b[sigT21:_cons], _b[sigT31:_cons],  _b[sigT10:_cons], _b[sigT20:_cons], _b[sigT41:_cons], _b[sigT51:_cons], _b[sigT61:_cons], `sigT40', _b[sigf11:_cons], _b[sigf12:_cons], _b[sigf21:_cons],  _b[sigf22:_cons], _b[p1:_cons],  _b[mu11:_cons],  _b[mu21:_cons],  _b[rho1:_cons], _b[rho2:_cons]
	mat b = e(b)
	foreach i in locus_std irrespons_std {
		forvalues j=0/1 {
			mat score _xb`i'`j' = b, eq(`i'`j')
			gen _r`i'`j'=`i'-_xb`i'`j'
			drop _xb`i'`j'
		}
		gen _r`i'=_r`i'1
		replace _r`i'=_r`i'0 if `choice'==0
	}
	foreach i in selfest_std categradeMathSc_std rankclassscore_std {
		mat score _xb`i' = b, eq(`i'1)
		gen _r`i'=`i'-_xb`i'
		drop _xb`i'
	}
	if inlist("`corr'","step6","step7") {
		drop _rselfest_std 
		if "`corr'"=="step6" {
			est use Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_step6
			local aT311 = _b[aT311:_cons]
			local sigT30 = _b[sigT30:_cons]
		}	
		est use Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_Zt0_step5
		mat b = e(b)
		if "`corr'"=="step6" mat inval = _b[av1:_cons], _b[av2:_cons], _b[aT111:_cons], _b[aT211:_cons], `aT311', _b[aT411:_cons], _b[aT421:_cons], _b[aT511:_cons], _b[aT521:_cons], _b[aT110:_cons], _b[aT210:_cons], _b[aT410:_cons], _b[aT420:_cons], _b[sigT11:_cons], _b[sigT21:_cons], _b[sigT31:_cons], _b[sigT10:_cons], _b[sigT20:_cons], `sigT30', _b[sigT41:_cons], _b[sigT51:_cons], _b[sigT61:_cons], _b[sigT40:_cons], _b[sigf11:_cons], _b[sigf12:_cons], _b[sigf21:_cons],  _b[sigf22:_cons], _b[p1:_cons],  _b[mu11:_cons],  _b[mu21:_cons],  _b[rho1:_cons], _b[rho2:_cons]
	
		local i categradeLangSS_std 
		forvalues j=0/1 {
			mat score _xb`i'`j' = b, eq(`i'`j')
			gen _r`i'`j'=`i'-_xb`i'`j'
			drop _xb`i'`j'
		}
		gen _r`i'=_r`i'1
		replace _r`i'=_r`i'0 if `choice'==0
		
		if inlist("`corr'","step7") {
			drop _rrankclassscore_std
			est use Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_step7
			local sigT60 = _b[sigT60:_cons]
			est use Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_Zt0_step6
			mat b = e(b)
			mat inval = _b[av1:_cons], _b[av2:_cons], _b[aT111:_cons], _b[aT211:_cons], _b[aT311:_cons], _b[aT411:_cons], _b[aT421:_cons], _b[aT511:_cons], _b[aT521:_cons], _b[aT110:_cons], _b[aT210:_cons], _b[aT410:_cons], _b[aT420:_cons], _b[sigT11:_cons], _b[sigT21:_cons], _b[sigT31:_cons], _b[sigT10:_cons], _b[sigT20:_cons], _b[sigT30:_cons], _b[sigT41:_cons], _b[sigT51:_cons], _b[sigT61:_cons], _b[sigT40:_cons], `sigT60', _b[sigf11:_cons], _b[sigf12:_cons], _b[sigf21:_cons],  _b[sigf22:_cons], _b[p1:_cons],  _b[mu11:_cons],  _b[mu21:_cons],  _b[rho1:_cons], _b[rho2:_cons]
			local i selfest_std 
			forvalues j=0/1 {
				mat score _xb`i'`j' = b, eq(`i'`j')
				gen _r`i'`j'=`i'-_xb`i'`j'
				drop _xb`i'`j'
			}
			gen _r`i'=_r`i'1
			replace _r`i'=_r`i'0 if `choice'==0		
		}		
	}

	local controls "ageinmonths male oldersiblings youngsiblings lnmonthinc_pc urban liveswbothparents onlymother fathereduc2yColl fathereduc4yColl fathereducGS"
	if "`corr'"=="step5" local testslist "_rlocus_std _rirrespons_std _rselfest_std categradeLangSS_std _rcategradeMathSc_std _rrankclassscore_std"
	if "`corr'"=="step6" local testslist "_rlocus_std _rirrespons_std selfest_std _rcategradeLangSS_std _rcategradeMathSc_std _rrankclassscore_std"
	if "`corr'"=="step7" local testslist "_rlocus_std _rirrespons_std _rselfest_std _rcategradeLangSS_std _rcategradeMathSc_std rankclassscore_std"
	
	gen uno=1		
	
	cap log close
	log using Results/logs/FirstStageJoint`name'_w`w'_newcodeHHM_Zt0_`corr'.txt, text replace

	cap noisily heterofactor `outvar' `controls' if wave==`w' & sample==1, /// 
		treatindbef(`choice') /// 
		instrum(`controls' moveout_adj2002 quit_adj2002) /// 
		scores(`testslist') indvarsc() exp1(uno) exp2(`controls') /// 
		factors(2) triangular joint difficult fdistonly initialreg inipar(inval)
	est save Results/Regs/FirstStageJoint`name'_w`w'_newcodeHHM_Zt0_`corr', replace
	ml display
	log close	
}	

********************************************************************************
* 4. Preparing for second stage or simulations
********************************************************************************

xtset id wave

if inlist("`corr'","second","simul","bootstrap","bootstrapMPC") {

	local u = `w'-1
	gen f`choice' = f.`choice'
	if "`outvar'"=="inCollege" local f "f." // College is in w=6
	if "`outvar'"!="" gen fw5`outvar' = f.f.f.f.`f'`outvar'	
	 
	bys schwave: egen nschwave=count(schwave)
	drop if nschwave<=2 & wave==2 // This gets rid of scharew where there is only one or two kids (8 in wave2)	

	****************************************************************************
	* 4.1 Creating variables: Instruments
	****************************************************************************
	
	bys scharew: egen nbullies = sum(bullydum) if wave==1
	gen nbullies2 = nbullies^2
	qui loom bullydum schwave
	rename bullydumloo pbullies
	forvalues i=1/5 {
		replace q33a1`i'w = . if inlist(q33a1`i'w,0,9)
	}
	alpha q33a11w q33a12w q33a13w q33a14w q33a15w if wave==1, gen(FamilyViolence)
	qui sum FamilyViolence
	gen FamilyTroubled = (FamilyViolence>`r(mean)') if FamilyViolence<. & wave==1
	
	alpha q33a11w q33a12w q33a13w q33a14w q33a15w if wave==2, gen(FamilyViolenceW2)
	qui sum FamilyViolenceW2
	gen FamilyTroubledW2 = (FamilyViolenceW2>`r(mean)') if FamilyViolenceW2<. & wave==2
	replace FamilyTroubled=FamilyTroubledW2 if wave==2
	drop FamilyTroubledW2
	
	qui loom FamilyTroubled schwave
	bys schwave: egen pfamtroubled = mean(FamilyTroubled)
	replace FamilyTroubledloo = pfamtroubled if FamilyTroubledloo<.12
	drop pfamtroubled
	rename FamilyTroubledloo pfamtroubled
	gen pfamtroubled2 = pfamtroubled^2	
	loom male schwave
	
	****************************************************************************
	* 4.2 Calling inputs from first stage
	****************************************************************************
	
	// Residuals
	est use Results/Regs/FirstStageJointRR_w`u'_newcodeHHM_step3
	mat b = e(b)
	foreach i in locus_std irrespons_std {
		forvalues j=0/1 {
			mat score _xb`i'`j' = b, eq(`i'`j')
			gen _r`i'`j'=`i'-_xb`i'`j'
			drop _xb`i'`j'
		}
		gen _r`i'=_r`i'1
		replace _r`i'=_r`i'0 if `choice'==0
	}
	local i categradeMathSc_std 
	mat score _xb`i' = b, eq(`i'1)
	gen _r`i'=`i'-_xb`i'
	drop _xb`i'
	
	local counter = 4
	foreach i in categradeLangSS_std selfest_std rankclassscore_std {
		local counter = `counter'+1
		est use Results/Regs/FirstStageJointRR_w`u'_newcodeHHM_step`counter'
		mat b = e(b)
		forvalues j=0/1 {
			mat score _xb`i'`j' = b, eq(`i'`j')
			gen _r`i'`j'=`i'-_xb`i'`j'
			drop _xb`i'`j'
		}
		gen _r`i'=_r`i'1
		replace _r`i'=_r`i'0 if `choice'==0
	}	
			
	// Input from 1st Stage: Parameters and Initial values
	mat score ga1 = b, eq(`choice')
	local av11 = _b[av1:_cons]
	local av12 = _b[av2:_cons]
	if "`model'"=="choiceonly" mat inval = 1,0, b[1,"aT111:_cons"], b[1,"aT211:_cons"], b[1,"aT311:_cons"], b[1,"aT411:_cons"], b[1,"aT421:_cons"], b[1,"aT511:_cons"], b[1,"aT521:_cons"], b[1,"aT110:_cons"], b[1,"aT210:_cons"], b[1,"aT410:_cons"], b[1,"aT420:_cons"]
	if "`model'"=="roy" mat inval = 1,0, 0,0,0,0, b[1,"aT111:_cons"], b[1,"aT211:_cons"], b[1,"aT311:_cons"], b[1,"aT411:_cons"], b[1,"aT421:_cons"], b[1,"aT511:_cons"], b[1,"aT521:_cons"], b[1,"aT110:_cons"], b[1,"aT210:_cons"], b[1,"aT410:_cons"], b[1,"aT420:_cons"], 0, 0
	if "`model'"=="roynl" {
		mat inval = 1,0, 0,0,0,0, b[1,"aT111:_cons"], b[1,"aT211:_cons"], b[1,"aT311:_cons"], b[1,"aT411:_cons"], b[1,"aT421:_cons"], b[1,"aT511:_cons"], b[1,"aT521:_cons"], b[1,"aT110:_cons"], b[1,"aT210:_cons"], b[1,"aT410:_cons"], b[1,"aT420:_cons"]
		local nl nl
		if "`outvar'"=="psychoprob" mat inval = -.1325974,-.0362954,-.4135057,-.0331533,-.1523523, .0083473, .5130343,-.4593246, .4707245, .2719384, .6466551,  .302758, .6222078, .4990288,-.4967574, .2628264, .6579352
		if "`outvar'"=="sick" mat inval = -.1108914,-.0193337,-.1051011,-.0814394,-.1907865,-.0394945,  .466377,-.4274771, .4386292, .2586844, .6552536,  .298466, .6178434,  .504513,-.5037771, .2673893, .6545695	
	}		
	if "`model'"=="roy" & "`outvar'"=="StressFriends_std" mat inval = -.120218, -.021616,-.4610409, .0935234, -.192505, .0657626, .4695187,-.4390588, .4615773, .2303567, .6634809, .2894691, .6175688, .5048648,-.4969909, .2688657, .6541236, .0165671,-.0468381
	if "`model'"=="roy" & "`outvar'"=="StressSchool_std" mat inval = -.113299,-.0222987,-.2050834, .3165406,-.0943183, .2966126, .4669587, -.422081, .4506559, .2495285, .6574324, .2948452, .6158604, .5045346,-.4971254,  .269627, .6534288,-.0517392,-.0592633
	if "`model'"=="roy" & "`outvar'"=="StressParent_std" mat inval = -.1135496,-.0217761,-.0639918, .1413399,-.1145378, .1724603, .4696412,-.4251594, .4465338, .2485881, .6572476, .2946763,  .616301, .5061879,-.5000008, .2682465, .6544444, .0052366,-.0336773
	if "`model'"=="roy" & "`outvar'"=="StressTotal_std" mat inval = -.1191001,-.0216567,-.4133017, .2133323,-.2414057, .1788123, .4702675,-.4287858,  .472791, .2286121, .6628406, .2852092, .6186138, .5040558,-.4971194,  .263985, .6557039,-.0453272, -.056225
	if "`model'"=="roy" & "`outvar'"=="StressPoverty_std" & "`name'"=="pviolence" mat inval = -.1196484,-.0212973,-.3221061, .0791054,-.2523401, .0094884, .4591186,-.4412017,  .459578, .2340167, .6596169,  .290611, .6167241, .5048534,-.5054394, .2627173, .6556422,  -.08316,-.0472571
	if "`model'"=="roy" & "`outvar'"=="drink" & "`name'"=="pbullies" mat inval = -.1249848, -.0254949, -.0396705,  -.065688, -.0558258, -.0112225,  .5063172, -.4657547,  .4589822,  .2621652,  .6520173,  .2997081,  .6226063,  .5000998, -.4991533,  .2675884,  .6557423,  -.743201, -.7132561
	if "`model'"=="choiceonly" mat inval = -.1216069,-.0287734, .5103456,-.4614681,  .455535, .2682766, .6501681, .3020955, .6220383, .5021934,-.4950252, .2693185, .6554589
	if "`model'"=="roy" & "`outvar'"=="psychoprob" mat inval = -.123054,-.0256226, -.105727,-.0062823,-.0233951, .0031861, .5131662,-.4650992,  .459659, .2676349, .6503263, .2997643, .6225704, .4991234,-.4981382, .2671285, .6558982,-1.006706,-1.285079
	mat sTlist = b[1,"sigT11:_cons"], b[1,"sigT21:_cons"], b[1,"sigT31:_cons"], b[1,"sigT10:_cons"], b[1,"sigT20:_cons"], b[1,"sigT30:_cons"], b[1,"sigT41:_cons"], b[1,"sigT51:_cons"], b[1,"sigT61:_cons"], b[1,"sigT40:_cons"], b[1,"sigT60:_cons"]
	mat distpar = b[1,"sigf11:_cons"], b[1,"sigf12:_cons"], b[1,"sigf21:_cons"], b[1,"sigf22:_cons"], b[1,"p1:_cons"], b[1,"mu11:_cons"], b[1,"mu21:_cons"], b[1,"rho1:_cons"], b[1,"rho2:_cons"]	
	mat distpar = b
	mat Vdistpar = e(V)
	
	****************************************************************************
	* 4.3 Defining the model to run
	****************************************************************************
	
	* Following referee will use instruments in wave 1 as opposed to contemporaneous to victimization. Replaced `fZ' for `Z' intreatment eq.
	xtset id wave
	local fZ
	foreach i in `Z' {
		gen f`i' = f`u'.`i'
		local fZ "`fZ' f`i'"
	}
	
	local FEproxy "totalstudentgrowth avg_moveout_adj avg_movein_adj avg_quit_adj"
	local Z
	if "`name'"=="pbullies" local Z "pbullies"
	else if "`name'"=="pviolence" local Z "pfamtroubled pfamtroubled2 `FEproxy'"	
	else if "`name'"=="pbulviol" local Z "pbullies pfamtroubled pfamtroubled2 `FEproxy'"
	else if "`name'"=="NC_invest" local Z "pbullies pfamtroubled pfamtroubled2 ParentHarmony_std ParentControl_std ParentVerbPhyAbuse_std schquality schenviron `FEproxy'"
	

	local controls "ageinmonths male oldersiblings youngsiblings lnmonthinc_pc urban liveswbothparents onlymother fathereduc2yColl fathereduc4yColl fathereducGS"	
	local controlsd "`controls'"
	
	if "`simsmod'"=="" qui sum fw5`outvar' if wave==1 & sample==1, d
	if inlist("`outvar'","depre_std","StressImage_std") local filter " & inrange(fw5`outvar',`r(p1)',`r(p99)')"	

	****************************************************************************
	* 4.4 Defining the outcome for simulations
	****************************************************************************
	
	if inlist("`corr'","bootstrap","bootstrapMPC") {
		est use Results/Regs/`choice'_`model'W`w'JointRR`name'_`outvar'_newcodeHHM_sgZ		
		mat bout = e(b)
		mat Vout = e(V)		
	}

}

********************************************************************************
* 5. Second stage: Includes treatment equation and outcome equations
********************************************************************************

if inlist("`corr'","second") {	
	if "`model'"=="choiceonly" local yvar "irrespons"  // a place holder
	if "`model'"=="choiceonly" local outvar
	else local yvar "fw5`outvar'"
						
	cap log close
	log using Results/logs/`choice'_`model'W`w'JointRR`name'_`outvar'_newcodeHHM_sgZ.txt, text replace  // _sgZ stands for samegender and inst are lagged

	cap noisily heterofactor `yvar' `controls' if wave==1 & sample==1 `filter', treatind(f`choice') treatindbef(`choice') /// 
		instrum(`controlsd' maleloo `Z' /*`fZ'*/) /// 
		scores(locus_std irrespons_std selfest_std categradeLangSS_std categradeMathSc_std rankclassscore_std) /// 
		resvar1(_rlocus_std) resvar2(_rirrespons_std) resvar3(_rselfest_std) resvar4(_rcategradeLangSS_std) resvar5(_rcategradeMathSc_std) resvar6(_rrankclassscore_std) /// 
		indvarsc(`controls') stvec(sTlist) jointdist(distpar) gavar(ga1) av1(`av11') av2(`av12') /// 
		factors(2) triangular joint difficult scndstponly initialreg inipar(inval) `model' 		
	est save Results/Regs/`choice'_`model'W`w'JointRR`name'_`outvar'_newcodeHHM_sgZ, replace
	ml display
	log close						
}

********************************************************************************
* 6. Simulations
********************************************************************************

if inlist("`corr'","bootstrap") {	

	// here prefixes matter: fw5 and f`choice'. But wee need to clean them put within the simulation code
	// simsmod: could be "dist" to simulate the distribution by treatment status
	if "`simsmod'"!="" local simdistloc `"simulsave("Results/Simulations/HHM/bs")"'

	simulate _b, reps(200) saving(Results/Simulations/HHM/bs/`choice'_`outvar'_JointRR`name'`nl'_trHHM_sgZ_bs`simsmod', replace): /// 
		simulfactjoint_bsparam fw5`outvar' `controls' if wave==1 & sample==1 `filter', /// 	
			idvar(id) treatind(f`choice') instrum(`controls' maleloo `Z') /// 
			fulloutparlist(bout) v(Vout) ///
			pardist(distpar) parv(Vdistpar) ///
			ndraws(200) grid(10) ette `simsmod' `simdistloc' `nl'
	
	if "`simsmod'"=="" {
	// Tables
		use Results/Simulations/HHM/bs/`choice'_`outvar'_JointRR`name'`nl'_trHHM_sgZ_bs, clear
		foreach AT in A /*T*/ {
			forvalues f=1/2 {
				file open E`AT'TEf`f' using Results/Simulations/HHM/bs/`choice'_`outvar'_JointRR`name'`nl'_trHHM_sgZ_bs_E`AT'TEf`f'`f'.txt, write replace
				forvalues i = 1/10 {
					qui sum _b_E`AT'TE_`f'`f'_`i'
					local cl = `r(mean)'-(1.96*`r(sd)')
					local cr = `r(mean)'+(1.96*`r(sd)')
					file write E`AT'TEf`f' "`r(mean)'" _tab "`cl'" _tab "`cr'" _n
				}				
				file close E`AT'TEf`f'
			}
			
			file open E`AT'TEf12 using Results/Simulations/HHM/bs/`choice'_`outvar'_JointRR`name'`nl'_trHHM_sgZ_bs_E`AT'TEf12.txt, write replace
			file open s`AT'TEf12 using Results/Simulations/HHM/bs/`choice'_`outvar'_JointRR`name'`nl'_trHHM_sgZ_bs_s`AT'TEf12.txt, write replace
			forvalues i = 1/10 {
				forvalues h = 1/10 {
					qui sum _b_E`AT'TE_12_`i'`h'
					file write E`AT'TEf12 "`r(mean)'" _tab
					file write s`AT'TEf12 "`r(sd)'" _tab 
					if `h'==10 {
						file write E`AT'TEf12 "`r(mean)'" _n
						file write s`AT'TEf12 "`r(sd)'" _n 
					} 
				}
			}	
			file close E`AT'TEf12
			file close s`AT'TEf12
			
		}			
	}
	
}

if inlist("`corr'","bootstrapMPC") {	
	// Policy Change
	
	gen pbulliesmpc = pbullies/2
	gen pfamtroubledmpc = pfamtroubled
	replace pfamtroubledmpc = pfamtroubled/2 if pfamtroubled>.4
	gen pfamtroubled2mpc =  pfamtroubledmpc^2
	
	simulate _b, reps(200) saving(Results/Simulations/HHM/bs/mpc/`choice'_`outvar'_JointRR`name'`nl'_trHHM_sgZ_bs`simsmod', replace): /// 
		simulfactjoint_bsparam_mpc fw5`outvar' `controls' if wave==1 & sample==1 `filter', /// 	
			idvar(id) treatind(f`choice') instrum(`controls' maleloo `Z') /// 
			fulloutparlist(bout) v(Vout) ///
			pardist(distpar) parv(Vdistpar) ///
			ndraws(200) grid(10) mpcvar(pbullies) `simsmod' `simdistloc' `nl'
	exit 	
	// Tables
	use Results/Simulations/HHM/bs/mpc/`choice'_`outvar'_JointRR`name'`nl'_trHHM_sgZ_bs`simsmod', clear
	
	local AT "A"
	file open E`AT'TEf12 using Labor/vkorea/Results/Simulations/HHM/bs/mpc/`choice'_`outvar'_JointRR`name'`nl'_trHHM_sgZ_bs_E`AT'TEf12.txt, write replace
	file open s`AT'TEf12 using Labor/vkorea/Results/Simulations/HHM/bs/mpc/`choice'_`outvar'_JointRR`name'`nl'_trHHM_sgZ_bs_s`AT'TEf12.txt, write replace
	forvalues i = 1/10 {
		forvalues h = 1/10 {
			qui sum _b_E`AT'TE_12_`i'`h'
			file write E`AT'TEf12 "`r(mean)'" _tab
			file write s`AT'TEf12 "`r(sd)'" _tab 
			if `h'==10 {
				file write E`AT'TEf12 "`r(mean)'" _n
				file write s`AT'TEf12 "`r(sd)'" _n 
			} 
		}
	}	
	file close E`AT'TEf12
	file close s`AT'TEf12
						
}

********************************************************************************
* 7. Results Tables
********************************************************************************

	****************************************************************************
	* Table 4
	****************************************************************************

if "`step'"=="regyd" {
	cd Results/Regs 
	xtset id wave
	foreach o in depre_std smoke drink sick psychoprob satisfied inCollege StressFriends_std StressParent_std StressSchool_std StressPoverty_std StressTotal_std {
		local filter
		local f
		local repapp append		
		if "`o'"=="inCollege" local f "f."
		qui gen fw5`o' = f.f.f.f.`f'`o'
		qui sum fw5`o' if wave==1 & sample==1, d
		if inlist("`o'","depre_std") local filter " & inrange(fw5`o',`r(p1)',`r(p99)')"
		if "`o'"=="depre_std" local repapp replace
		qui reg fw5`o' `event'dum `controls' if wave==1 & sample==1 `filter'
		qui outreg2 using reduced_HHM_2Ftr_`event'_keep.tex, tex(frag) bdec(3) `repapp' ctitle("`o'") keep(`event'dum) addtext(Observables, Y, Test Scores, N)
		qui reg fw5`o' `event'dum `controls' locus_std irrespons_std selfest_std categradeLangSS_std categradeMathSc_std rankclassscore_std if wave==1 & sample==1 `filter'
		qui outreg2 using reduced_HHM_2Ftr_`event'_keep.tex, tex(frag) bdec(3) append  ctitle("") keep(`event'dum) addtext(Observables, Y, Test Scores, Y)
	}
	cd
}

	****************************************************************************
	* Table 5
	****************************************************************************

if "`corr'"=="tableD" {

	foreach i in "" pbullies pviolence pbulviol {

		est use Results/Regs/bullieddum_choiceonlyW2JointRR`i'__newcodeHHM_sgZ
		est sto m`i'	
		if "`i'"=="pviolence" test pfamtroubled pfamtroubled2
		if "`i'"=="pbulviol" test pbullies pfamtroubled pfamtroubled2
		if inlist("`i'","pviolence","pbulviol") {
			estadd scalar Chi2 = r(chi2)
			estadd scalar pchi2 = r(p)
		}	
	}	
	esttab m mpbullies mpviolence mpbulviol using "Results/Regs/Table_choiceonlyW2JointRR_sgZ.tex", replace ///
		se(3) starlevels(* 0.10 ** 0.05 *** 0.01) b(%9.3f)	wide ///
		mtitles("(1)" "(2)" "(3)" "(4)")	///
		mgroups("Coeff." "Coeff." "Coeff." "Coeff.", pattern(1 1 1 1))	///
		drop(totalstudentgrowth avg_moveout_adj avg_movein_adj avg_quit_adj aT111:_cons aT211:_cons aT311:_cons aT411:_cons aT421:_cons aT511:_cons aT521:_cons aT110:_cons aT210:_cons aT410:_cons aT420:_cons ) ///
		coeflabels(ageinmonths "Age in Months" male "Male" oldersiblings "OlderSiblings" /*
		*/ oldersiblings "OlderSiblings" youngsiblings "YoungSiblings" /*
		*/ lnmonthinc_pc "Lnmonthincpc" onlymen "SingleGender:Men" urban Urban /* 
		*/ onlywomen "SingleGender:Women" liveswbothparents LivesBothParents /* 
		*/ onlymother LivesOnlyMother fathereduc2yColl FatherEduc2yColl /* 
		*/ fathereduc4yColl FatherEduc4yColl fathereducGS FatherEducGS /*
		*/ pbullies "\% Peer Bullies" pfamtroubled "\% Violent Fam" pfamtroubled2 "\% Violent Fam$^2$" /*
		*/ "av21:_cons" "Non-Cognitive Skills" "av22:_cons" "Cognitive Skills" _cons Constant) ///
		nonotes nonumbers nogaps stats(Chi2 pchi2 N, labels(" $\Chi^2$" " $\Pr > \Chi^2$") fmt(%9.3f %9.3f %9.0f))
		
	/* This didnt come out exactly perfect. Needs a little bit of editing by hand which will yiel a new file */
}

	****************************************************************************
	* Table 6
	****************************************************************************

if "`corr'"=="loadings" {

	foreach level in 90 95 99 {
		local crval`level' = invnormal(0.5*(1 - `level'/100) + `level'/100)	
		di `crval`level''
	}
	
	cap program drop sig
	program sig, rclass
		args t crval90 crval95 crval99	
		if (`crval99'<`t') local sig "***"
		else if (`crval95'<`t') local sig "**"
		else if (`crval90'<`t') local sig "*"
		else local sig ""
		return local sig "`sig'"
	end
	
	cd  Results/Regs
	
	local outs = 6
	local cols = 2*`outs'
	forvalues i=1/`cols' {
		local cc "`cc'c"
		local empty " `empty' & "
	}
	local list1 "depre_std drink smoke satisfied sick psychoprob"
	local list2 "inCollege StressFriends_std StressParent_std StressSchool_std StressTotal_std StressPoverty_std"
	
	local labdepre_std "Depression"
	local labdrink "Drink"
	local labsmoke "Smoke"
	local labsatisfied "Life Satisfaction"
	local labsick "Sick"
	local labpsychoprob "Mental Health"
	local labinCollege "inCollege$ ^\dagger$"
	local labStressFriends_std "Stress: Friends"
	local labStressParent_std "Stress: Parent" 
	local labStressSchool_std "Stress: School" 
	local labStressTotal_std "Stress: Total" 
	local labStressPoverty_std "Stress: Poverty"
	
	cap file close loads
	file open loads using Loads`choice'_`model'W`w'JointRR`name'_sgZ.tex, write replace
	file write loads "\begin{tabular}{l`cc'}" _n
	file write loads "\hline " _n
	
	local count = 0
	forvalues l=1/2 {
		forvalues i = 1/`outs' {
			local count = `count' + 1
			file write loads " & \multicolumn{2}{c}{(`count')}" 
		}
		file write loads "\tabularnewline " _n
		foreach i in `list`l'' {
			file write loads " & \multicolumn{2}{c}{`lab`i''}" 
		}
		file write loads "\tabularnewline " _n
		file write loads " \emph{Bullied} "
		foreach i in `list`l'' {
			file write loads " & $ D=0 $ & $ D=1 $ " 
		}	
		file write loads "\tabularnewline \hline " _n
		file write loads "`empty' \tabularnewline " _n
		
		forvalues skl=1/2 {
			if `skl'==1 file write loads "Non-Cogn Skills "
			if `skl'==2 file write loads "Cognitive Skills "
			foreach i in `list`l'' {
				est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
				forvalues d=0/1 {
					local b = string(round(_b[a`d'`skl':_cons],0.001),"%9.3f")
					local t = abs(_b[a`d'`skl':_cons]/_se[a`d'`skl':_cons])
					sig `t' `crval90' `crval95' `crval99'
					local sig `r(sig)'		
					file write loads " & `b'`sig' "
				}	
			}
			file write loads "\tabularnewline " _n
			foreach i in `list`l'' {
				est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
				forvalues d=0/1 {	
					local s = string(round(_se[a`d'`skl':_cons],0.001),"%9.3f")
					file write loads " & (`s') "
				}
			}	
			file write loads "\tabularnewline " _n
		}
		file write loads "`empty' \tabularnewline " _n
		file write loads "Observations "
		foreach i in `list`l'' {
			est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
			local N = e(N)
			file write loads " & \multicolumn{2}{c}{`N'}"
		}
		file write loads "\tabularnewline \hline " _n
	}
	file write loads "\end{tabular}" 
	file close loads
	cd
}

	****************************************************************************
	* Table 7
	****************************************************************************

if "`corr'"=="GoodFitY" {

	bys schwave: egen nschwave=count(schwave)
	drop if nschwave<=2 & wave==2
	xtset id wave
		
	foreach outvar in depre_std smoke drink sick psychoprob satisfied inCollege StressFriends_std StressParent_std StressSchool_std StressPoverty_std StressTotal_std {	
		local f
		local filter
		di "`outvar'"
		if "`outvar'"=="inCollege" local f "f." // College is in w=6
		gen fw5`outvar' = f.f.f.`f'`outvar'	
		
		if inlist("`outvar'","depre_std","StressImage_std") qui sum fw5`outvar' if wave==2 & sample==1, d
		if inlist("`outvar'","depre_std","StressImage_std") local filter " & inrange(fw5`outvar',`r(p1)',`r(p99)')" // & lnmonthinc_pc!=."	
			
		forvalues d = 0/1 {
			qui sum fw5`outvar' if bullieddum==`d' & sample==1 & wave==2 `filter'
			local my`d'`outvar' = `r(mean)'
			local sy`d'`outvar' = `r(sd)'
		}	
		
	}	
	
	local list1 "depre_std smoke sick satisfied"
	local list2 "inCollege psychoprob StressFriends_std StressParent_std"
	local list3 "StressSchool_std StressPoverty_std StressTotal_std drink"
	
	cap file close _all
	file open GF using Results/Simulations/HHM/bs/`choice'_GF_JointRR`name'_trHHM_sgZ_bs.tex, write replace
	file write GF "\begin{tabular}{ccccccccc}" _n "\hline" _n "\hline" _n
	
	forvalues l=1/3 {
		if `l'==1 file write GF " & \multicolumn{2}{c}{Depression} & \multicolumn{2}{c}{Smoking} & \multicolumn{2}{c}{Sick} & \multicolumn{2}{c}{Life Satisfaction}\tabularnewline" _n
		if `l'==2 file write GF " & \multicolumn{2}{c}{College} & \multicolumn{2}{c}{Mental Health} & \multicolumn{2}{c}{Stress: Friends } & \multicolumn{2}{c}{Stress: Parents}\tabularnewline" _n
		if `l'==3 file write GF " & \multicolumn{2}{c}{Stress: School} & \multicolumn{2}{c}{Stress: Poverty} & \multicolumn{2}{c}{Stress: Total} & \multicolumn{2}{c}{Drink}\tabularnewline" _n
		file write GF " & Data & Model & Data & Model & Data & Model & Data & Model\tabularnewline" _n "\hline " _n

		forvalues d=0/1 {
			file write GF " $ E\left[Y_{`d'}\left|D=`d'\right.\right]$ " 
			foreach out in `list`l'' {
				use Results/Simulations/HHM/bs/`choice'_`out'_JointRR`name'_trHHM_sgZ_bs, clear
				qui sum _b_EY`d'
				local EY`d' = string(round(`r(mean)',0.0001),"%9.4f")
				local my`d'`out' = string(round(`my`d'`out'',0.0001),"%9.4f")
				file write GF " & `my`d'`out'' & `EY`d'' "
			}
			file write GF " \tabularnewline" _n 
			foreach out in `list`l'' {
				use Results/Simulations/HHM/bs/`choice'_`out'_JointRR`name'_trHHM_sgZ_bs, clear
				qui sum _b_sY`d'
				local sY`d' = string(round(`r(mean)',0.001),"%9.3f")	
				local sy`d'`out' = string(round(`sy`d'`out'',0.001),"%9.3f")
				file write GF " & (`sy`d'`out'') & (`sY`d'') "
			}
			file write GF " \tabularnewline" _n
		}
		file write GF " \hline " _n
	}	
	file write GF " \hline " _n _n "\end{tabular}" 
	file close GF

}						

	****************************************************************************
	* Table 8
	****************************************************************************	

if "`corr'"=="tablesATEATT" {

	cap file close _all
	file open ATEtab using Results/Simulations/HHM/bs/`choice'_ATE_JointRR`name'_trHHM_sgZ_bs.tex, write replace

	file write ATEtab "\begin{tabular}{lcccccc}" _n "\hline" _n
	file write ATEtab "& Depre & Smoking & Drinking & Sick & Mental Health & Satisfied \\ \hline" _n
	foreach AT in A T {
		file write ATEtab "`AT'TE "
		foreach out in depre_std smoke drink sick psychoprob satisfied {
			use Results/Simulations/HHM/bs/`choice'_`out'_JointRR`name'_trHHM_sgZ_bs, clear
			qui sum _b_E`AT'TE
			local me`AT'TE = string(round(`r(mean)',0.0001),"%9.4f")
			local se`AT'TE`out' = string(round(`r(sd)',0.0001),"%9.4f")
			local stars
			if (abs(`r(mean)'/`r(sd)')>=1.645) local stars "*"
			if (abs(`r(mean)'/`r(sd)')>=1.96) local stars "**"
			if (abs(`r(mean)'/`r(sd)')>=2.5758) local stars "***"	
			file write ATEtab "& `me`AT'TE'`stars' "
			if "`out'"=="satisfied" file write ATEtab " \\" _n
		}
		file write ATEtab " "
		foreach out in depre_std smoke drink sick psychoprob satisfied {
			file write ATEtab "& (`se`AT'TE`out'') "
			if "`out'"=="satisfied" file write ATEtab " \\" _n
		}
	}
	file write ATEtab "& & & & & & \\" _n "\hline" _n
	file write ATEtab "& inCollege & Stress:Friends & Stress:Parent & Stress:School & Stress:Poverty & Stress:Total \\ \hline" _n
	foreach AT in A T {
		file write ATEtab "`AT'TE "
		foreach out in inCollege StressFriends_std StressParent_std StressSchool_std StressPoverty_std StressTotal_std {
			use Results/Simulations/HHM/bs/`choice'_`out'_JointRR`name'_trHHM_sgZ_bs, clear
			qui sum _b_E`AT'TE
			local me`AT'TE = string(round(`r(mean)',0.0001),"%9.4f")
			local se`AT'TE`out' = string(round(`r(sd)',0.0001),"%9.4f")
			local stars
			if (abs(`r(mean)'/`r(sd)')>=1.645) local stars "*"
			if (abs(`r(mean)'/`r(sd)')>=1.96) local stars "**"
			if (abs(`r(mean)'/`r(sd)')>=2.5758) local stars "***"	
			file write ATEtab "& `me`AT'TE'`stars' "
			if "`out'"=="StressTotal_std" file write ATEtab " \\" _n
		}
		file write ATEtab " "
		foreach out in inCollege StressFriends_std StressParent_std StressSchool_std StressPoverty_std StressTotal_std {
			file write ATEtab "& (`se`AT'TE`out'') "
			if "`out'"=="StressTotal_std" file write ATEtab " \\"_n
		}
	}
	file write ATEtab "\hline" _n "\end{tabular}" 
	file close ATEtab

}	

	****************************************************************************
	* Table B.1
	****************************************************************************	

if "`corr'"=="tabFS" {

	foreach level in 90 95 99 {
		local crval`level' = invnormal(0.5*(1 - `level'/100) + `level'/100)	
		di `crval`level''
	}
	
	cap program drop sig
	program sig, rclass
		args t crval90 crval95 crval99	
		if (`crval99'<`t') local sig "***"
		else if (`crval95'<`t') local sig "**"
		else if (`crval90'<`t') local sig "*"
		else local sig ""
		return local sig "`sig'"
	end

	cd  Results/Regs
	
	local outs = 6
	local cols = 2*`outs'
	forvalues i=1/12 {
		local cc "`cc'c"
		local empty " `empty' & "
	}
	
	local list1 "locus_std irrespons_std selfest_std categradeLangSS_std categradeMathSc_std rankclassscore_std"
	local controls "ageinmonths male oldersiblings youngsiblings lnmonthinc_pc urban liveswbothparents onlymother fathereduc2yColl fathereduc4yColl fathereducGS moveout_adj2002 quit_adj2002"	
	local lablocus_std "Locus Control"
	local labirrespons_std "Irresponsibility"
	local labselfest_std "Self-Esteem"
	local labcategradeLangSS_std "Language - SocStudies"
	local labcategradeMathSc_std "Math - Sci"
	local labrankclassscore_std "ClassScore"

	cap file close loads
	file open loads using FullTabFS_W1_JointRR_Zt0.tex, write replace
	file write loads "\begin{tabular}{l`cc'}" _n
	file write loads "\hline " _n	
	file write loads " & "
	
	foreach i in locus_std irrespons_std selfest_std categradeLangSS_std {
		file write loads " & \multicolumn{2}{c}{`lab`i''}" 
	}
	file write loads " & `labcategradeMathSc_std' "
	file write loads " & \multicolumn{2}{c}{`labrankclassscore_std'} \tabularnewline" _n 
	
	file write loads " & Bullied "
	foreach i in locus_std irrespons_std selfest_std categradeLangSS_std {
		file write loads " & $ D=0 $ & $ D=1 $ " 
	}
	file write loads " & - "
	file write loads " & $ D=0 $ & $ D=1 $ \tabularnewline \hline" _n
	file write loads "`empty' \tabularnewline " _n
	
	
	foreach v in `controls' {
		if "`v'" == "ageinmonths" loca tit "Age in Months"
		if "`v'" == "male" loca tit "Male"
		if "`v'" == "oldersiblings" loca tit "Oldersiblings"
		if "`v'" == "youngsiblings" loca tit "Youngsiblings"
		if "`v'" == "lnmonthinc_pc" loca tit "Lnmonthincpc"
		if "`v'" == "urban"  loca tit "Urban"
		if "`v'" == "liveswbothparents" loca tit "Lives BothParents"
		if "`v'" == "onlymother"  loca tit "Lives OnlyMother"
		if "`v'" == "fathereduc2yColl" loca tit "Fathereduc2yColl"
		if "`v'" == "fathereduc4yColl" loca tit "Fathereduc4yColl"
		if "`v'" == "fathereducGS" loca tit "FathereducGS"
		if "`v'" == "moveout_adj2002" loca tit "Leavers $\tau_{-1}$"
		if "`v'" == "quit_adj2002" loca tit "Dropouts $\tau_{-1}$"
		
		// Bullied column
		est use FirstStageJointRR_w1_newcodeHHM_Zt0_step7
		local b = string(round(_b[bullieddum:`v'],0.001),"%9.3f")
		local t = abs(_b[bullieddum:`v']/_se[bullieddum:`v'])
		sig `t' `crval90' `crval95' `crval99'
		local sig `r(sig)'		
		file write loads " `tit' & `b'`sig' "
		
		if inlist("`v'","moveout_adj2002","quit_adj2002")==0 {
			// First 2 scores
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
			foreach i in locus_std irrespons_std {
				forvalues d=1(-1)0 {
					local b = string(round(_b[`i'`d':`v'],0.001),"%9.3f")
					local t = abs(_b[`i'`d':`v']/_se[`i'`d':`v'])
					sig `t' `crval90' `crval95' `crval99'
					local sig `r(sig)'		
					file write loads " & `b'`sig' "		
				}
			}
			// Third score
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step6
			local i selfest_std 
			forvalues d=1(-1)0 {
				local b = string(round(_b[`i'`d':`v'],0.001),"%9.3f")
				local t = abs(_b[`i'`d':`v']/_se[`i'`d':`v'])
				sig `t' `crval90' `crval95' `crval99'
				local sig `r(sig)'		
				file write loads " & `b'`sig' "		
			}
			// Fourth Score
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step5
			local i categradeLangSS_std 
			forvalues d=1(-1)0 {
				local b = string(round(_b[`i'`d':`v'],0.001),"%9.3f")
				local t = abs(_b[`i'`d':`v']/_se[`i'`d':`v'])
				sig `t' `crval90' `crval95' `crval99'
				local sig `r(sig)'		
				file write loads " & `b'`sig' "		
			}
			// Fifth Score
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
			local i categradeMathSc_std
			local d = 1
			local b = string(round(_b[`i'`d':`v'],0.001),"%9.3f")
			local t = abs(_b[`i'`d':`v']/_se[`i'`d':`v'])
			sig `t' `crval90' `crval95' `crval99'
			local sig `r(sig)'		
			file write loads " & `b'`sig' "	
			// Sixth Score
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step7
			local i rankclassscore_std 
			forvalues d=1(-1)0 {
				local b = string(round(_b[`i'`d':`v'],0.001),"%9.3f")
				local t = abs(_b[`i'`d':`v']/_se[`i'`d':`v'])
				sig `t' `crval90' `crval95' `crval99'
				local sig `r(sig)'		
				file write loads " & `b'`sig' "		
			}	
		}
		else file write loads "&  &  &  &  &  &  &  &  &  &"
		file write loads "\tabularnewline " _n
		
		// // Std Error
		// Bullied column
		est use FirstStageJointRR_w1_newcodeHHM_Zt0_step7
		local s = string(round(_se[bullieddum:`v'],0.001),"%9.3f")
		file write loads " & (`s') "			

		if inlist("`v'","moveout_adj2002","quit_adj2002")==0 {
			// First 2 scores
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
			foreach i in locus_std irrespons_std {
				forvalues d=1(-1)0 {
					local s = string(round(_se[`i'`d':`v'],0.001),"%9.3f")
					file write loads " & (`s') "		
				}
			}
			// Third score
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step6
			local i selfest_std 
			forvalues d=1(-1)0 {
				local s = string(round(_se[`i'`d':`v'],0.001),"%9.3f")
				file write loads " & (`s') "		
			}
			// Fourth Score
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step5
			local i categradeLangSS_std 
			forvalues d=1(-1)0 {
				local s = string(round(_se[`i'`d':`v'],0.001),"%9.3f")
				file write loads " & (`s') "		
			}
			// Fifth Score
			est use FirstStageJointRR_w1_newcodeHHM_step3
			local i categradeMathSc_std
			local d = 1
			local s = string(round(_se[`i'`d':`v'],0.001),"%9.3f")
			file write loads " & (`s') "	
			// Sixth Score
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step7
			local i rankclassscore_std 
			forvalues d=1(-1)0 {
				local s = string(round(_se[`i'`d':`v'],0.001),"%9.3f")
				file write loads " & (`s') "		
			}	
		}
		else file write loads "&  &  &  &  &  &  &  &  &  &"
		file write loads "\tabularnewline " _n		
	}
	
	// Skills
	forvalues skl=1/2 {
		if `skl'==1 file write loads "Non-Cogn Skills "
		if `skl'==2 file write loads "Cognitive Skills "
				
		// Bullied column
		est use FirstStageJointRR_w1_newcodeHHM_Zt0_step7
		local b = string(round(_b[av`skl':_cons],0.001),"%9.3f")
		local t = abs(_b[av`skl':_cons]/_se[av`skl':_cons])
		sig `t' `crval90' `crval95' `crval99'
		local sig `r(sig)'		
		file write loads " & `b'`sig' "
		
		if `skl'==1 {
			// First 2 scores
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
			local counter = 0
			foreach i in locus_std irrespons_std {
				local counter = `counter' + 1
				forvalues d=1(-1)0 {
					local b = string(round(_b[aT`counter'`skl'`d':_cons],0.001),"%9.3f")
					local t = abs(_b[aT`counter'`skl'`d':_cons]/_se[aT`counter'`skl'`d':_cons])
					sig `t' `crval90' `crval95' `crval99'
					local sig `r(sig)'		
					file write loads " & `b'`sig' "		
				}
			}
			// Third score
			local counter = `counter' + 1
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step6
			local b = string(round(_b[aT`counter'`skl'1:_cons],0.001),"%9.3f")
			local t = abs(_b[aT`counter'`skl'1:_cons]/_se[aT`counter'`skl'1:_cons])
			sig `t' `crval90' `crval95' `crval99'
			local sig `r(sig)'		
			file write loads " & `b'`sig' & 1 "	
		}
		if `skl'==2 file write loads " & & & & & & "		
		if `skl'==2 local counter = 3
		// Fourth Score
		local counter = `counter' + 1
		est use FirstStageJointRR_w1_newcodeHHM_Zt0_step5		
		forvalues d=1(-1)0 {
			local b = string(round(_b[aT`counter'`skl'`d':_cons],0.001),"%9.3f")
			local t = abs(_b[aT`counter'`skl'`d':_cons]/_se[aT`counter'`skl'`d':_cons])
			sig `t' `crval90' `crval95' `crval99'
			local sig `r(sig)'		
			file write loads " & `b'`sig' "		
		}		
		// Fifth Score
		local counter = `counter' + 1
		est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
		local b = string(round(_b[aT`counter'`skl'1:_cons],0.001),"%9.3f")
		local t = abs(_b[aT`counter'`skl'1:_cons]/_se[aT`counter'`skl'1:_cons])
		sig `t' `crval90' `crval95' `crval99'
		local sig `r(sig)'		
		file write loads " & `b'`sig' "			
		// Sixth Score
		if `skl'==1 file write loads " &  &  \tabularnewline " _n
		if `skl'==2 file write loads " & 1 & 1 \tabularnewline " _n		
		
		// // Std Error
		// Bullied column
		est use FirstStageJointRR_w1_newcodeHHM_Zt0_step7
		local s = string(round(_se[av`skl':_cons],0.001),"%9.3f")
		file write loads " & (`s') "			
		
		if `skl'==1 {
			// First 2 scores
			local counter = 0
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
			foreach i in locus_std irrespons_std {
				local counter = `counter' + 1
				forvalues d=1(-1)0 {
					local s = string(round(_se[aT`counter'`skl'`d':_cons],0.001),"%9.3f")
					file write loads " & (`s') "		
				}
			}
			// Third score
			local counter = `counter' + 1
			est use FirstStageJointRR_w1_newcodeHHM_Zt0_step6
			local s = string(round(_se[aT`counter'`skl'1:_cons],0.001),"%9.3f")
			file write loads " & (`s') & $ \blacksquare $ "		
		}
		if `skl'==2 file write loads " & & & & & & "
		if `skl'==2 local counter = 3
		// Fourth Score
		local counter = `counter' + 1
		est use FirstStageJointRR_w1_newcodeHHM_Zt0_step5
		local i categradeLangSS_std 
		forvalues d=1(-1)0 {
			local s = string(round(_se[aT`counter'`skl'`d':_cons],0.001),"%9.3f")
			file write loads " & (`s') "		
		}
		// Fifth Score
		local counter = `counter' + 1
		est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
		local i categradeMathSc_std
		local d = 1
		local s = string(round(_se[aT`counter'`skl'1:_cons],0.001),"%9.3f")
		file write loads " & (`s') "	
		// Sixth Score
		if `skl'==1 file write loads " &  &  \tabularnewline " _n
		if `skl'==2 file write loads " & $ \blacksquare $ & $ \blacksquare $ \tabularnewline " _n			
	}	
		
	// Constant
	local v _cons 
	loca tit "Constant"
		
	// Bullied column
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step7
	local b = string(round(_b[bullieddum:`v'],0.001),"%9.3f")
	local t = abs(_b[bullieddum:`v']/_se[bullieddum:`v'])
	sig `t' `crval90' `crval95' `crval99'
	local sig `r(sig)'		
	file write loads " `tit' & `b'`sig' "
		
	// First 2 scores
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
	foreach i in locus_std irrespons_std {
		forvalues d=1(-1)0 {
			local b = string(round(_b[`i'`d':`v'],0.001),"%9.3f")
			local t = abs(_b[`i'`d':`v']/_se[`i'`d':`v'])
			sig `t' `crval90' `crval95' `crval99'
			local sig `r(sig)'		
			file write loads " & `b'`sig' "		
		}
	}
	// Third score
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step6
	local i selfest_std 
	forvalues d=1(-1)0 {
		local b = string(round(_b[`i'`d':`v'],0.001),"%9.3f")
		local t = abs(_b[`i'`d':`v']/_se[`i'`d':`v'])
		sig `t' `crval90' `crval95' `crval99'
		local sig `r(sig)'		
		file write loads " & `b'`sig' "		
	}
	// Fourth Score
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step5
	local i categradeLangSS_std 
	forvalues d=1(-1)0 {
		local b = string(round(_b[`i'`d':`v'],0.001),"%9.3f")
		local t = abs(_b[`i'`d':`v']/_se[`i'`d':`v'])
		sig `t' `crval90' `crval95' `crval99'
		local sig `r(sig)'		
		file write loads " & `b'`sig' "		
	}
	// Fifth Score
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
	local i categradeMathSc_std
	local d = 1
	local b = string(round(_b[`i'`d':`v'],0.001),"%9.3f")
	local t = abs(_b[`i'`d':`v']/_se[`i'`d':`v'])
	sig `t' `crval90' `crval95' `crval99'
	local sig `r(sig)'		
	file write loads " & `b'`sig' "	
	// Sixth Score
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step7
	local i rankclassscore_std 
	forvalues d=1(-1)0 {
		local b = string(round(_b[`i'`d':`v'],0.001),"%9.3f")
		local t = abs(_b[`i'`d':`v']/_se[`i'`d':`v'])
		sig `t' `crval90' `crval95' `crval99'
		local sig `r(sig)'		
		file write loads " & `b'`sig' "		
	}	
	file write loads "\tabularnewline " _n
	
	// // Std Error
	// Bullied column
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step7
	local s = string(round(_se[bullieddum:`v'],0.001),"%9.3f")
	file write loads " & (`s') "			
	
	// First 2 scores
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
	foreach i in locus_std irrespons_std {
		forvalues d=1(-1)0 {
			local s = string(round(_se[`i'`d':`v'],0.001),"%9.3f")
			file write loads " & (`s') "		
		}
	}
	// Third score
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step6
	local i selfest_std 
	forvalues d=1(-1)0 {
		local s = string(round(_se[`i'`d':`v'],0.001),"%9.3f")
		file write loads " & (`s') "		
	}
	// Fourth Score
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step5
	local i categradeLangSS_std 
	forvalues d=1(-1)0 {
		local s = string(round(_se[`i'`d':`v'],0.001),"%9.3f")
		file write loads " & (`s') "		
	}
	// Fifth Score
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step3
	local i categradeMathSc_std
	local d = 1
	local s = string(round(_se[`i'`d':`v'],0.001),"%9.3f")
	file write loads " & (`s') "	
	// Sixth Score
	est use FirstStageJointRR_w1_newcodeHHM_Zt0_step7
	local i rankclassscore_std 
	forvalues d=1(-1)0 {
		local s = string(round(_se[`i'`d':`v'],0.001),"%9.3f")
		file write loads " & (`s') "		
	}	
	file write loads "\tabularnewline " _n		
	file write loads "`empty' \tabularnewline " _n
	local N = e(N)
	file write loads "Observations & \multicolumn{12}{c}{`N'} \tabularnewline \hline" _n

	file write loads "\end{tabular}" 
	file close loads
	cd
}

	****************************************************************************
	* Table C.1
	****************************************************************************	

if "`corr'"=="reduced" {
	cd Results/Regs 
	local controls "ageinmonths male oldersiblings youngsiblings lnmonthinc_pc urban liveswbothparents onlymother fathereduc2yColl fathereduc4yColl fathereducGS"	
	xtset id wave
	foreach o in depre_std smoke drink sick psychoprob satisfied inCollege StressFriends_std StressParent_std StressSchool_std StressPoverty_std StressTotal_std {
		local filter
		local f
		local repapp append		
		if "`o'"=="inCollege" local f "f."
		qui gen fw5`o' = f.f.f.f.`f'`o'
		qui sum fw5`o' if wave==1 & sample==1, d
		if inlist("`o'","depre_std","StressImage_std") local filter " & inrange(fw5`o',`r(p1)',`r(p99)')"
		if "`o'"=="depre_std" local repapp replace
		qui reg fw5`o' `controls' locus_std irrespons_std selfest_std categradeLangSS_std categradeMathSc_std rankclassscore_std if wave==1 & sample==1 `filter'
		qui outreg2 using reduced_outcomes_on_tests.tex, tex(frag) bdec(3) `repapp'  ctitle("") drop(`controls') nocons 
		drop fw5`o'
	}
	cd
}

	****************************************************************************
	* Table C.2
	****************************************************************************	

if "`corr'"=="loadsnochoice" {
	
	local name
	foreach level in 90 95 99 {
		local crval`level' = invnormal(0.5*(1 - `level'/100) + `level'/100)	
		di `crval`level''
	}
	
	cap program drop sig
	program sig, rclass
		args t crval90 crval95 crval99	
		if (`crval99'<`t') local sig "***"
		else if (`crval95'<`t') local sig "**"
		else if (`crval90'<`t') local sig "*"
		else local sig ""
		return local sig "`sig'"
	end

	
	cd  Results/Regs
	
	local outs = 6
	local cols = 1*`outs'
	forvalues i=1/`cols' {
		local cc "`cc'c"
		local empty " `empty' & "
	}
	local list1 "depre_std drink smoke satisfied sick psychoprob"
	local list2 "inCollege StressFriends_std StressParent_std StressSchool_std StressTotal_std StressPoverty_std"
	
	local labdepre_std "Depre"
	local labdrink "Drink"
	local labsmoke "Smoke"
	local labsatisfied "Satisfied"
	local labsick "Sick"
	local labpsychoprob "Mental H."
	local labinCollege "inCollege$ ^\dagger$"
	local labStressFriends_std "Stress:"
	local labStressParent_std "Stress:" 
	local labStressSchool_std "Stress:" 
	local labStressTotal_std "Stress:" 
	local labStressPoverty_std "Stress:"
	local labStressFriends_std2 "Friends"
	local labStressParent_std2 "Parent" 
	local labStressSchool_std2 "School" 
	local labStressTotal_std2 "Total" 
	local labStressPoverty_std2 "Poverty"	
	
	cap file close loads
	file open loads using Loads_`model'W`w'JointRR`name'_sgZ.tex, write replace
	file write loads "\begin{tabular}{l`cc'}" _n
	file write loads "\hline " _n
	
	local count = 0
	forvalues l=1/2 {
		forvalues i = 1/`outs' {
			local count = `count' + 1
			file write loads " & (`count')" 
		}
		file write loads "\tabularnewline " _n
		foreach i in `list`l'' {
			file write loads " & `lab`i''"
		}
		file write loads "\tabularnewline " _n
		if `l'==2 {
			foreach i in `list`l'' {
				file write loads " & `lab`i'2'"
			}
		}
		file write loads "\tabularnewline \hline " _n
		file write loads "`empty' \tabularnewline " _n
		
		forvalues skl=1/2 {
			if `skl'==1 file write loads "Non-Cogn Skills "
			if `skl'==2 file write loads "Cognitive Skills "
			foreach i in `list`l'' {
				est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
				
				local b = string(round(_b[a2`skl':_cons],0.001),"%9.3f")
				local t = abs(_b[a2`skl':_cons]/_se[a2`skl':_cons])
				sig `t' `crval90' `crval95' `crval99'
				local sig `r(sig)'		
				file write loads " & `b'`sig' "					
			}
			file write loads "\tabularnewline " _n
			foreach i in `list`l'' {
				est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ			
				local s = string(round(_se[a2`skl':_cons],0.001),"%9.3f")
				file write loads " & (`s') "
			}	
			file write loads "\tabularnewline " _n
		}
		file write loads "`empty' \tabularnewline " _n
		file write loads "Observations "
		foreach i in `list`l'' {
			est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
			local N = e(N)
			file write loads " & `N'"
		}
		file write loads "\tabularnewline \hline " _n
	}
	file write loads "\end{tabular}" 
	file close loads
	cd
}


	****************************************************************************
	* Appendix D
	****************************************************************************	

if "`step'"=="IV" {
	
	cd Results/Regs 
	
	local Tests "locus_std irrespons_std selfest_std categradeLangSS_std categradeMathSc_std rankclassscore_std"
	gen region = 1 if inrange(areaw,100,158)
	replace region = 2 if inrange(areaw,200,306)
	replace region = 3 if inrange(areaw,312,357)
	replace region = 4 if inrange(areaw,360,409)
	replace region = 5 if inrange(areaw,411,506)
	replace region = 6 if inrange(areaw,513,550)
	replace region = 7 if inrange(areaw,560,597)
	replace region = 8 if inrange(areaw,600,678)
	replace region = 9 if inrange(areaw,680,699)
	replace region = 10 if inrange(areaw,700,799)
	
	qui xtset id wave
	qui gen fw5smoke = f.f.f.f.smoke
	
	****************************************************************************
	* Table D.1
	****************************************************************************	

	foreach i in pbullies "pfamtroubled pfamtroubled2" "pbullies pfamtroubled pfamtroubled2" {
		local repapp append	
		if "`i'"=="pbullies" local repapp replace
		qui xtreg `event'dum `i' `controls' `Tests' if wave==1 & sample==1 & fw5smoke!=., fe i(region)
		if "`i'"=="pbullies" test pbullies +ageinmonths+ male+ oldersiblings+ youngsiblings+ lnmonthinc_pc +urban +liveswbothparents +onlymother +fathereduc2yColl +fathereduc4yColl+ fathereducGS +locus_std+ irrespons_std+ selfest_std +categradeLangSS_std +categradeMathSc_std+ rankclassscore_std +_cons=0 
		if "`i'"=="pfamtroubled pfamtroubled2" test pfamtroubled + pfamtroubled2 +ageinmonths+ male+ oldersiblings+ youngsiblings+ lnmonthinc_pc +urban +liveswbothparents +onlymother +fathereduc2yColl +fathereduc4yColl+ fathereducGS +locus_std+ irrespons_std+ selfest_std +categradeLangSS_std +categradeMathSc_std+ rankclassscore_std +_cons=0 
		if "`i'"=="pbullies pfamtroubled pfamtroubled2" test pbullies + pfamtroubled + pfamtroubled2 +ageinmonths+ male+ oldersiblings+ youngsiblings+ lnmonthinc_pc +urban +liveswbothparents +onlymother +fathereduc2yColl +fathereduc4yColl+ fathereducGS +locus_std+ irrespons_std+ selfest_std +categradeLangSS_std +categradeMathSc_std+ rankclassscore_std +_cons=0 
		local F = string(round(`r(F)',.001),"%9.3f")
		local p = string(round(`r(p)',.001),"%9.3f")
		qui outreg2 using IV_FS_HHM_2Ftr_`event'_keep.tex, tex(frag) bdec(3) `repapp' ctitle("`o'") keep(`i') nocons adds(F-test, "`F'", Prob > F, "`p'")
	}
	drop fw5smoke
	
	****************************************************************************
	* Table D.2
	****************************************************************************	

		
	foreach o in depre_std smoke drink sick psychoprob satisfied inCollege StressFriends_std StressParent_std StressSchool_std StressPoverty_std StressTotal_std {
		qui xtset id wave
		local filter
		local f
		local repapp append		
		if "`o'"=="inCollege" local f "f."
		qui gen fw5`o' = f.f.f.f.`f'`o'
		qui sum fw5`o' if wave==1 & sample==1, d
		if inlist("`o'","depre_std","StressImage_std") local filter " & inrange(fw5`o',`r(p1)',`r(p99)')"
		if "`o'"=="depre_std" local repapp replace
		qui xtset region
		qui xtivreg fw5`o' `controls' `Tests' (`event'dum = pbullies)if wave==1 & sample==1 `filter', fe
		qui outreg2 using IV_HHM_2Ftr_`event'_keep.tex, tex(frag) bdec(3) `repapp' ctitle("`o'") keep(`event'dum) addtext(Bullies, Y, Troub. Fam., N) nocons
		qui xtivreg fw5`o' `controls' `Tests' (`event'dum = pfamtroubled pfamtroubled2)if wave==1 & sample==1 `filter', fe
		qui outreg2 using IV_HHM_2Ftr_`event'_keep.tex, tex(frag) bdec(3) append  ctitle("") keep(`event'dum) addtext(Bullies, N, Troub. Fam., Y) nocons
		qui xtivreg fw5`o' `controls' `Tests' (`event'dum = pbullies pfamtroubled pfamtroubled2)if wave==1 & sample==1 `filter', fe
		qui outreg2 using IV_HHM_2Ftr_`event'_keep.tex, tex(frag) bdec(3) append  ctitle("") keep(`event'dum) addtext(Bullies, Y, Troub. Fam., Y) nocons

		qui ivtreatreg fw5`o' `event'dum `controls' `Tests' if wave==1 & sample==1 `filter', model(probit-2sls) iv(pbullies)
		qui outreg2 using IV_Prob_2Ftr_`event'_keep.tex, tex(frag) bdec(3) `repapp' ctitle("`o'") keep(`event'dum) addtext(Bullies, Y, Troub. Fam., N) nocons
		qui ivtreatreg fw5`o' `event'dum `controls' `Tests' if wave==1 & sample==1 `filter', model(probit-2sls) iv(pfamtroubled pfamtroubled2)
		qui outreg2 using IV_Prob_2Ftr_`event'_keep.tex, tex(frag) bdec(3) append  ctitle("") keep(`event'dum) addtext(Bullies, N, Troub. Fam., Y) nocons
		qui ivtreatreg fw5`o' `event'dum `controls' `Tests' if wave==1 & sample==1 `filter', model(probit-2sls) iv(pbullies pfamtroubled pfamtroubled2)
		qui outreg2 using IV_Prob_2Ftr_`event'_keep.tex, tex(frag) bdec(3) append  ctitle("") keep(`event'dum) addtext(Bullies, Y, Troub. Fam., Y) nocons
				
		drop fw5`o'
	}
	cd
}


	****************************************************************************
	* Appendix F: Robustness of the Results in Low-mean Outcomes
	****************************************************************************	

		************************************************************************
		* Table F.1
		************************************************************************

if "`corr'"=="GoodFitYnl" {

	local my0sick = 0.0639
	local my1sick = 0.1187
	local my0psychoprob = .0874 
	local my1psychoprob = .1851 

	local sy0sick = .245
	local sy1sick = .324
	local sy0psychoprob = .282 
	local sy1psychoprob = .389 
	
	local nl nl
	local list1 "sick psychoprob"
	
	cap file close _all
	file open GF using Results/Simulations/HHM/bs/`choice'_GF_JointRR`name'`nl'_trHHM_sgZ_bs.tex, write replace
	file write GF "\begin{tabular}{ccccc}" _n "\hline" _n "\hline" _n
	
	forvalues l=1/1 {
		if `l'==1 file write GF " & \multicolumn{2}{c}{Sick} & \multicolumn{2}{c}{Mental Health} \tabularnewline" _n
		file write GF " & Data & Model & Data & Model \tabularnewline" _n "\hline " _n

		forvalues d=0/1 {
			file write GF " $ E\left[Y_{`d'}\left|D=`d'\right.\right]$ " 
			foreach out in `list`l'' {
				use Results/Simulations/HHM/bs/`choice'_`out'_JointRR`name'`nl'_trHHM_sgZ_bs, clear
				qui sum _b_EY`d'
				local EY`d' = string(round(`r(mean)',0.0001),"%9.4f")
				local my`d'`out' = string(round(`my`d'`out'',0.0001),"%9.4f")
				file write GF " & `my`d'`out'' & `EY`d'' "
			}
			file write GF " \tabularnewline" _n 
			foreach out in `list`l'' {
				use Results/Simulations/HHM/bs/`choice'_`out'_JointRR`name'`nl'_trHHM_sgZ_bs, clear
				qui sum _b_sY`d'
				local sY`d' = string(round(`r(mean)',0.001),"%9.3f")	
				local sy`d'`out' = string(round(`sy`d'`out'',0.001),"%9.3f")
				file write GF " & (`sy`d'`out'') & (`sY`d'') "
			}
			file write GF " \tabularnewline" _n
		}
		file write GF " \hline " _n
	}	
	file write GF " \hline " _n _n "\end{tabular}" 
	file close GF

}						


		************************************************************************
		* Table F.2
		************************************************************************

if "`corr'"=="tablesATEATTnl" {
	local nl nl
	cap file close _all
	file open ATEtab using Results/Simulations/HHM/bs/`choice'_ATE_JointRR`name'`nl'_trHHM_sgZ_bs.tex, write replace
	file write ATEtab "\begin{tabular}{lcc}" _n "\hline" _n
	file write ATEtab "& Sick & Mental Health \\ \hline" _n
	foreach AT in A T {
		file write ATEtab "`AT'TE "
		foreach out in sick psychoprob {
			use Results/Simulations/HHM/bs/`choice'_`out'_JointRR`name'`nl'_trHHM_sgZ_bs, clear
			qui sum _b_E`AT'TE
			local me`AT'TE = string(round(`r(mean)',0.0001),"%9.4f")
			local se`AT'TE`out' = string(round(`r(sd)',0.0001),"%9.4f")
			local stars
			if (abs(`r(mean)'/`r(sd)')>=1.645) local stars "*"
			if (abs(`r(mean)'/`r(sd)')>=1.96) local stars "**"
			if (abs(`r(mean)'/`r(sd)')>=2.5758) local stars "***"	
			file write ATEtab "& `me`AT'TE'`stars' "
			if "`out'"=="psychoprob" file write ATEtab " \\" _n
		}
		file write ATEtab " "
		foreach out in sick psychoprob {
			file write ATEtab "& (`se`AT'TE`out'') "
			if "`out'"=="psychoprob" file write ATEtab " \\" _n
		}
	}
	file write ATEtab "\hline" _n "\end{tabular}" 
	file close ATEtab

}	


	****************************************************************************
	* Appendix G: Tables G.1 and G.2
	****************************************************************************	

if "`corr'"=="tabSSout" {

	foreach level in 90 95 99 {
		local crval`level' = invnormal(0.5*(1 - `level'/100) + `level'/100)	
		di `crval`level''
	}
	
	cap program drop sig
	program sig, rclass
		args t crval90 crval95 crval99	
		if (`crval99'<`t') local sig "***"
		else if (`crval95'<`t') local sig "**"
		else if (`crval90'<`t') local sig "*"
		else local sig ""
		return local sig "`sig'"
	end
	
	cd  Results/Regs
	
	local outs = 6
	local cols = 2*`outs'
	forvalues i=1/`cols' {
		local cc "`cc'c"
		local empty " `empty' & "
	}
	local list1 "depre_std drink smoke satisfied sick psychoprob"
	local list2 "inCollege StressFriends_std StressParent_std StressSchool_std StressTotal_std StressPoverty_std"
	local controls "ageinmonths male oldersiblings youngsiblings lnmonthinc_pc urban liveswbothparents onlymother fathereduc2yColl fathereduc4yColl fathereducGS"	
	
	local labdepre_std "Depression"
	local labdrink "Drink"
	local labsmoke "Smoke"
	local labsatisfied "Life Satisfaction"
	local labsick "Sick"
	local labpsychoprob "Mental Health"
	local labinCollege "inCollege$ ^\dagger$"
	local labStressFriends_std "Stress: Friends"
	local labStressParent_std "Stress: Parent" 
	local labStressSchool_std "Stress: School" 
	local labStressTotal_std "Stress: Total" 
	local labStressPoverty_std "Stress: Poverty"
	
	forvalues l=1/2 {
		cap file close loads
		file open loads using SSout`l'`choice'_`model'W`w'JointRR`name'_sgZ.tex, write replace
		file write loads "\begin{tabular}{l`cc'}" _n
		file write loads "\hline " _n
	
		forvalues i = 1/`outs' {
			file write loads " & \multicolumn{2}{c}{(`i')}" 
		}
		file write loads "\tabularnewline " _n
		foreach i in `list`l'' {
			file write loads " & \multicolumn{2}{c}{`lab`i''}" 
		}
		file write loads "\tabularnewline " _n
		file write loads " \emph{Bullied} "
		foreach i in `list`l'' {
			file write loads " & $ D=0 $ & $ D=1 $ " 
		}	
		file write loads "\tabularnewline \hline " _n
		file write loads "`empty' \tabularnewline " _n
		
		foreach v in `controls' {
			if "`v'" == "ageinmonths" loca tit "Age in Months"
			if "`v'" == "male" loca tit "Male"
			if "`v'" == "oldersiblings" loca tit "Oldersiblings"
			if "`v'" == "youngsiblings" loca tit "Youngsiblings"
			if "`v'" == "lnmonthinc_pc" loca tit "Lnmonthincpc"
			if "`v'" == "urban"  loca tit "Urban"
			if "`v'" == "liveswbothparents" loca tit "Lives BothParents"
			if "`v'" == "onlymother"  loca tit "Lives OnlyMother"
			if "`v'" == "fathereduc2yColl" loca tit "Fathereduc2yColl"
			if "`v'" == "fathereduc4yColl" loca tit "Fathereduc4yColl"
			if "`v'" == "fathereducGS" loca tit "FathereducGS"
			
			file write loads "`tit' "
		
			foreach i in `list`l'' {
				est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
				forvalues d=0/1 {
					local b = string(round(_b[fw5`i'`d':`v'],0.001),"%9.3f")
					local t = abs(_b[fw5`i'`d':`v']/_se[fw5`i'`d':`v'])
					sig `t' `crval90' `crval95' `crval99'
					local sig `r(sig)'		
					file write loads " & `b'`sig' "
				}			
			}
			file write loads "\tabularnewline " _n
			foreach i in `list`l'' {
				est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
				forvalues d=0/1 {
					local s = string(round(_se[fw5`i'`d':`v'],0.001),"%9.3f")
					file write loads " & (`s') "
				}			
			}		
			file write loads "\tabularnewline " _n
		}	
		// Skills
		forvalues skl=1/2 {
			if `skl'==1 file write loads "Non-Cogn Skills "
			if `skl'==2 file write loads "Cognitive Skills "
			foreach i in `list`l'' {
				est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
				forvalues d=0/1 {
					local b = string(round(_b[a`d'`skl':_cons],0.001),"%9.3f")
					local t = abs(_b[a`d'`skl':_cons]/_se[a`d'`skl':_cons])
					sig `t' `crval90' `crval95' `crval99'
					local sig `r(sig)'		
					file write loads " & `b'`sig' "
				}	
			}
			file write loads "\tabularnewline " _n
			foreach i in `list`l'' {
				est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
				forvalues d=0/1 {	
					local s = string(round(_se[a`d'`skl':_cons],0.001),"%9.3f")
					file write loads " & (`s') "
				}
			}	
			file write loads "\tabularnewline " _n
		}
		// Constant
		local v _cons
		file write loads "Constant "
		foreach i in `list`l'' {
			est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
			forvalues d=0/1 {
				local b = string(round(_b[fw5`i'`d':`v'],0.001),"%9.3f")
				local t = abs(_b[fw5`i'`d':`v']/_se[fw5`i'`d':`v'])
				sig `t' `crval90' `crval95' `crval99'
				local sig `r(sig)'		
				file write loads " & `b'`sig' "
			}			
		}
		file write loads "\tabularnewline " _n
		foreach i in `list`l'' {
			est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
			forvalues d=0/1 {
				local s = string(round(_se[fw5`i'`d':`v'],0.001),"%9.3f")
				file write loads " & (`s') "
			}			
		}		
		file write loads "\tabularnewline " _n		
				
		file write loads "`empty' \tabularnewline " _n
		file write loads "Observations "
		foreach i in `list`l'' {
			est use `choice'_`model'W`w'JointRR`name'_`i'_newcodeHHM_sgZ
			local N = e(N)
			file write loads " & \multicolumn{2}{c}{`N'}"
		}
		file write loads "\tabularnewline \hline " _n
		file write loads "\end{tabular}" 
		file close loads
	}
	
	cd
}


********************************************************************************
* 8. Results Figures
********************************************************************************

if "`corr'"=="variation" {

	cd  Results/Regs
	local controls "ageinmonths male oldersiblings youngsiblings lnmonthinc_pc urban liveswbothparents onlymother fathereduc2yColl fathereduc4yColl fathereducGS"	
	
	qui sum bullieddum if wave==1 & sample==1
	local p1=`r(mean)'
	local p0=1-`p1'
	local T=0
	foreach i in locus_std irrespons_std selfest_std categradeLangSS_std categradeMathSc_std rankclassscore_std {
		local T=`T'+1
		if inlist("`i'","categradeMathSc_std") {
			qui reg `i' `controls' if wave==1 & sample==1
			local TSS = e(mss) + e(rss)
			local MSS = e(mss)
			est use FirstStageJointRR_w1_newcodeHHM_step3
			local eSS = (exp(_b[sigT`T'1:_cons])^2)*(e(N)-(e(df_m)+2))			
			local FSS = round(`TSS '- `MSS' - `eSS', 0.001)
			di "Observables:"`MSS'/`TSS' " Endowments:" `FSS'/`TSS' " Residuals:" `eSS'/`TSS'			
		}
		else {
			forvalues d=0/1 {
				else qui reg `i' `controls' if wave==1 & sample==1 & bullieddum==`d'
				local TSS`d' = e(mss) + e(rss)
				local MSS`d' = e(mss)
				local N`d' = e(N)
			}	
			local TSS = `TSS0'+`TSS1'
			local MSS = `MSS0'+`MSS1'
//			local   N = `N0'+`N1'
			if inlist(`T',1,2) est use FirstStageJointRR_w1_newcodeHHM_step3
			if inlist(`T',3) est use FirstStageJointRR_w1_newcodeHHM_step6
			if inlist(`T',4) est use FirstStageJointRR_w1_newcodeHHM_step5
			if inlist(`T',6) est use FirstStageJointRR_w1_newcodeHHM_step7
			forvalues d=0/1 {
				local eSS`d' = `p`d''*(exp(_b[sigT`T'`d':_cons])^2)*(e(N)-(e(df_m)+2))			
			}
			local eSS = `eSS0'+`eSS1'
			local FSS = round(`TSS '- `MSS' - `eSS', 0.001)
			di "Observables:"`MSS'/`TSS' " Endowments:" `FSS'/`TSS' " Residuals:" `eSS'/`TSS'
		
		}
	}
	cd
}

if "`corr'"=="distrib" {
	qui do Labor/JoinTest/random_dist2f.ado
	cap drop mixt1
	cap drop mixt2
	est use Results/Regs/FirstStageJointRR_w1_newcodeHHM_step7
	
	local sigmamixt11 = _b[sigf11:_cons]
	local sigmamixt12 = _b[sigf12:_cons]
	local sigmamixt21 = _b[sigf21:_cons]
	local sigmamixt22 = _b[sigf22:_cons]
	local mixtprob = _b[p1:_cons]
	local mumixt1 = _b[mu11:_cons]
	local mumixt2 = _b[mu21:_cons]
	local rmixt1 = _b[rho1:_cons]
	local rmixt2 = _b[rho2:_cons]
	random_dist2f `sigmamixt11' `sigmamixt12' `sigmamixt21' `sigmamixt22' `mixtprob' `mumixt1' `mumixt2' `rmixt1' `rmixt2'
	keep mixt*
	sum mixt1,d
	keep if inrange(mixt1,`r(p1)',`r(p99)')
	sum mixt2,d
	keep if inrange(mixt2,`r(p1)',`r(p99)')	
	save Results/Simulations/HHM/JointDistribsRRW1, replace
	
	//export delimited using "/Users/msarzosa/Documents/UMD/Labor/Urzua/Korea/Results/Regs/SterHHMJoint/JointDistribsRRW1.csv", delimiter(tab) novarnames replace

	
}









